@@ -35,7 +35,6 @@ class Client(GooglePubSubClient):
     def pubsub_publish_pf_monitoring(self,
                                     topic: str,
                                     project_id:str,
-                                    firebase_api_key:str,
                                     monitoring_id: str,
                                     step: str,
                                     entity_id: str,
@@ -55,7 +54,6 @@ class Client(GooglePubSubClient):
         self.push_to_topic(project=project_id,
                     topic_name=topic,
                     parameters=parameters,
-                    firebase_api_key=firebase_api_key,
                     await_response=True)
         print(f"Published {status} message for entity {entity_id} and monitoring_id {monitoring_id}")
 
